==> cpl_5.3.1.orig.tar.gz: cpl-5.3.1/cplcore/cpl_imagelist.h <==
/* $Id: cpl_imagelist.h,v 1.6 2010/11/11 09:23:18 llundin Exp $
 *
 * This file is part of the ESO Common Pipeline Library
 * Copyright (C) 2001-2008 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*
 * $Author: llundin $
 * $Date: 2010/11/11 09:23:18 $
 * $Revision: 1.6 $
 * $Name: cpl-5_3_0-BRANCH $
 */

#ifndef CPL_IMAGELIST_H
#define CPL_IMAGELIST_H

/*-----------------------------------------------------------------------------
                                   New types
 -----------------------------------------------------------------------------*/

typedef struct _cpl_imagelist_ cpl_imagelist ;

/*-----------------------------------------------------------------------------
                                   Includes
 -----------------------------------------------------------------------------*/

#include "cpl_imagelist_io.h"
#include "cpl_imagelist_basic.h"

#endif

==> cpl_6.0.orig.tar.gz: cpl-6.0/cplcore/cpl_imagelist.h <==
/* $Id: cpl_imagelist.h,v 1.7 2011/04/08 08:43:28 llundin Exp $
 *
 * This file is part of the ESO Common Pipeline Library
 * Copyright (C) 2001-2008 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/*
 * $Author: llundin $
 * $Date: 2011/04/08 08:43:28 $
 * $Revision: 1.7 $
 * $Name: cpl-6_0 $
 */

#ifndef CPL_IMAGELIST_H
#define CPL_IMAGELIST_H

/*-----------------------------------------------------------------------------
                                   New types
 -----------------------------------------------------------------------------*/

typedef struct _cpl_imagelist_ cpl_imagelist;

/*-----------------------------------------------------------------------------
                                   Includes
 -----------------------------------------------------------------------------*/

#include "cpl_imagelist_io.h"
#include "cpl_imagelist_basic.h"

/*----------------------------------------------------------------------------*/
/**
 * @defgroup cpl_imagelist Imagelists
 *
 * This module provides functions to create, use, and destroy a
 *   @em cpl_imagelist.
 * A @em cpl_imagelist is an ordered list of cpl_images. All images in a list
 * must have the same pixel-type and the same dimensions.
 * 
 * @par Synopsis:
 * @code
 *   #include "cpl_imagelist.h"
 * @endcode
 */
/*----------------------------------------------------------------------------*/

#endif
